window.Gleam.initSearch([{"doc":"lenient_parse","title":"lenient_parse","content":"# lenient_parse\n\n[![Package Version](https://img.shields.io/hexpm/v/lenient_parse)](https://hex.pm/packages/lenient_parse)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lenient_parse/)\n\nA Gleam library providing lenient parsing functions for converting strings to float and integer values. This package offers more flexible parsing than the standard Gleam functions, similar to Python&#39;s built-in `float()` and `int()` functions.\n\n## Installation\n\n\n```sh\ngleam add lenient_parse\n```\n```gleam\nimport lenient_parse\nimport gleam/io\n\npub fn main() {\n  // --- Float parsing\n\n  // Parse a string containing an integer\n  &quot;1&quot; |&gt; lenient_parse.to_float |&gt; io.debug\n  // Ok(1.0)\n\n  // Parse a string containing a negative float\n  &quot;-5.001&quot; |&gt; lenient_parse.to_float |&gt; io.debug\n  // Ok(-5.001)\n\n  // Parse a more complex float with scientific notation\n  &quot;-1_234.567_8e-2&quot; |&gt; lenient_parse.to_float |&gt; io.debug\n  // Ok(-12.345678)\n\n  // --- Integer parsing\n\n  // Parse a string containing an integer\n  &quot;123&quot; |&gt; lenient_parse.to_int |&gt; io.debug\n  // Ok(123)\n\n  // Parse a string containing a negative integer with surrounding whitespace\n  &quot;  -123  &quot; |&gt; lenient_parse.to_int |&gt; io.debug\n  // Ok(-123)\n\n  // Parse a string containing an integer with underscores\n  &quot;1_000_000&quot; |&gt; lenient_parse.to_int |&gt; io.debug\n  // Ok(1000000)\n\n  // Parse a binary string\n  &quot;1000_0000&quot; |&gt; lenient_parse.to_int_with_base(base: 2) |&gt; io.debug\n  // Ok(128)\n\n  // Parse a hexadecimal string\n  &quot;DEAD_BEEF&quot; |&gt; lenient_parse.to_int_with_base(base: 16) |&gt; io.debug\n  // Ok(3735928559)\n}\n```\n\n## Developer Setup\n\nTo run the tests for this package, you&#39;ll need to [install `uv`](https://docs.astral.sh/uv/getting-started/installation/).\n","url":"index.html"},{"doc":"parse_error","title":"ParseError","content":"pub type ParseError {\n  EmptyString\n  WhitespaceOnlyString\n  InvalidUnderscorePosition(index: Int)\n  InvalidDecimalPosition(index: Int)\n  InvalidSignPosition(character: String, index: Int)\n  InvalidDigitPosition(character: String, index: Int)\n  OutOfBaseRange(\n    character: String,\n    value: Int,\n    base: Int,\n    index: Int,\n  )\n  InvalidExponentSymbolPosition(character: String, index: Int)\n  UnknownCharacter(character: String, index: Int)\n  InvalidBaseValue(base: Int)\n}\n\nEmptyString\n Represents an error when the input string is empty.\n\nWhitespaceOnlyString\n Represents an error when the input string contains only whitespace\n characters.\n\nInvalidUnderscorePosition(index: Int)\n Represents an error when an underscore is in an invalid position within\n the number string.\n\n - `index`: The position of the invalid underscore in the input string.\n\nInvalidDecimalPosition(index: Int)\n Represents an error when a decimal point is in an invalid position within\n the number string.\n\n - `index`: The position of the invalid decimal point in the input string.\n\nInvalidSignPosition(character: String, index: Int)\n Represents an error when a sign (+ or -) is in an invalid position within\n the number string.\n\n - `character`: The sign character that caused the error as a `String`.\n - `index`: The position of the invalid sign in the input string.\n\nInvalidDigitPosition(character: String, index: Int)\n Represents an error when a digit is in an invalid position within the\n number string.\n\n - `character`: The digit character that caused the error as a `String`.\n - `index`: The position of the invalid digit in the input string.\n\nOutOfBaseRange(\n  character: String,\n  value: Int,\n  base: Int,\n  index: Int,\n)\n Represents an error when a digit character is out of the valid range for\n the specified base.\n\n - `character`: The string representation of the out-of-range digit.\n - `value`: The integer value of the out-of-range digit.\n - `base`: The base in which the digit is out of range.\n - `index`: The position of the out-of-range digit in the input string.\n\nInvalidExponentSymbolPosition(character: String, index: Int)\n Represents an error when an exponent symbol (e or E) is in an invalid\n position within the number string.\n\n - `character`: The exponent symbol that caused the error as a `String`.\n - `index`: The position of the invalid exponent symbol in the input\n string.\n\nUnknownCharacter(character: String, index: Int)\n Represents an error when an invalid character is encountered during\n parsing.\n\n - `character`: The invalid character as a `String`.\n - `index`: The position of the invalid character in the input string.\n\nInvalidBaseValue(base: Int)\n Represents an error when the base provided for parsing is invalid.\n\n - `base`: The invalid base as an `Int`. The base must be between 2 and 36\n inclusive.\n\nSynonyms:\nparse_error.ParseError\nparse_error ParseError","url":"parse_error.html#ParseError"},{"doc":"parse_error","title":"parse_error","content":"","url":"parse_error.html"},{"doc":"lenient_parse","title":"to_float","content":"pub fn to_float(text text: String) -&gt; Result(Float, ParseError)\n Converts a string to a float using a more lenient parsing method than\n gleam&#39;s `float.parse()`. It behaves similarly to Python&#39;s `float()` built-in\n function.\nSynonyms:\nlenient_parse.to_float\nlenient_parse to_float","url":"lenient_parse.html#to_float"},{"doc":"lenient_parse","title":"to_int","content":"pub fn to_int(text text: String) -&gt; Result(Int, ParseError)\n Converts a string to an integer using a more lenient parsing method than\n gleam&#39;s `int.parse()`. It behaves similarly to Python&#39;s `int()` built-in\n function, using a default base of 10.\nSynonyms:\nlenient_parse.to_int\nlenient_parse to_int","url":"lenient_parse.html#to_int"},{"doc":"lenient_parse","title":"to_int_with_base","content":"pub fn to_int_with_base(\n  text text: String,\n  base base: Int,\n) -&gt; Result(Int, ParseError)\n Converts a string to an integer using a more lenient parsing method than\n gleam&#39;s `int.parse()`, allowing for a specified base. It behaves similarly\n to Python&#39;s `int()` built-in function with a base parameter.\nSynonyms:\nlenient_parse.to_int_with_base\nlenient_parse to_int_with_base","url":"lenient_parse.html#to_int_with_base"},{"doc":"lenient_parse","title":"lenient_parse","content":"","url":"lenient_parse.html"}]);